@@ -5,6 +5,7 @@ const executorch = {};
 const coreml = {};
 const vulkan = {};
 const xnnpack = {};
+const qnn = {};
 
 import * as base from './base.js';
 import * as python from './python.js';
@@ -298,8 +299,13 @@ executorch.Tensor = class {
         const program = target.program;
         if (tensor.extra_tensor_info) {
             throw new executorch.Error('Extra tensor info not implemented.');
-        } else if (program.constant_buffers) {
-            throw new executorch.Error('Constant buffers not implemented.');
+        } else if (Array.isArray(program.constant_buffer) && program.constant_buffer.length > 0) {
+            if (data_buffer_idx >= program.constant_buffer.length) {
+                throw new executorch.Error(`Constant buffer index out of range.`);
+            }
+            const buffer = program.constant_buffer[data_buffer_idx];
+            this.values = buffer.storage;
+            this.encoding = '<';
         } else if (tensor.allocation_info === null) {
             const constant_segment = program.constant_segment;
             const data_segment = program.segments[constant_segment.segment_index];
@@ -396,6 +402,10 @@ executorch.Reader = class {
                                 delegate.backend = vulkan.Reader.open(data, this);
                                 break;
                             }
+                            case 'QnnBackend': {
+                                delegate.backend = qnn.Reader.open(data, this);
+                                break;
+                            }
                             default: {
                                 throw new executorch.Error(`ExecuTorch delegate '${delegate.id}' not implemented.`);
                             }
@@ -1083,4 +1093,30 @@ coreml.Context = class {
     }
 };
 
+qnn.Reader = class {
+
+    static open(data, target) {
+        if (data.length >= 20) {
+            const reader = base.BinaryReader.open(data);
+            const magic = reader.uint32();
+            if (magic === 0x5678ABCD) {
+                return new qnn.Reader(reader, target);
+            }
+        }
+        return null;
+    }
+
+    constructor(reader, target) {
+        this.reader = reader;
+        this.target = target;
+        this.signature = reader.uint64();
+        this.size = reader.uint64();
+    }
+
+    async read() {
+        // https://github.com/pytorch/executorch/blob/main/backends/qualcomm/runtime/backends/QnnCustomProtocol.h
+        throw new executorch.Error('QNN backend not implemented.');
+    }
+};
+
 export const ModelFactory = executorch.ModelFactory;
\ No newline at end of file
