@@ -14,7 +14,8 @@ onnx.Version = {
     "IR_VERSION_2023_5_5": 9,
     "IR_VERSION_2024_3_25": 10,
     "IR_VERSION_2025_05_12": 11,
-    "IR_VERSION": 12
+    "IR_VERSION_2025_08_26": 12,
+    "IR_VERSION": 13
 };
 
 onnx.AttributeProto = class AttributeProto {
@@ -1597,7 +1598,9 @@ onnx.TensorProto.DataType = {
     "UINT4": 21,
     "INT4": 22,
     "FLOAT4E2M1": 23,
-    "FLOAT8E8M0": 24
+    "FLOAT8E8M0": 24,
+    "UINT2": 25,
+    "INT2": 26
 };
 
 onnx.TensorProto.Segment = class Segment {
